@@ -1,3 +1,6 @@
+import os
+
+
 def foo(x):
     pass
 
@@ -89,7 +92,7 @@ def loop_invariant_statement_while():
 
 def loop_invariant_statement_more_complex_while():
     """Catch basic loop-invariant function call."""
-    x = [1,2,3,4]
+    x = [1, 2, 3, 4]
     i = 6
     j = 0
     while j < 100:
@@ -155,7 +158,6 @@ def loop_invariant_statement_but_name_while():
     for _ in range(10_000):
         i  # [loop-invariant-statement]
 
-import os  # NOQA
 
 def test_dotted_import(items):
     for item in items:
@@ -164,3 +166,41 @@ def test_dotted_import(items):
 def even_worse_dotted_import(items):
     for item in items:
         val = os.path.exists(item)
+
+
+def loop_invariance_in_self_assignment():
+    class Foo:
+        n = 1
+
+        def loop(self):
+            i = 4
+            for self.n in range(4):
+                print(self.n)
+                len(i)  # [loop-invariant-statement]
+
+    def test(): #@
+        f = Foo()
+        f.loop()
+    test()
+
+
+def invariant_fstrings():
+    i = 1
+    for n in range(2):
+        print(f"{i}")  # [loop-invariant-statement]
+        print(f"{n}")
+        print(f"{i} + {n}")
+        print(f"{n} + {i}")
+
+def invariant_literals():
+    i = 1
+    for n in range(2):
+        d = {"x": i}  # [loop-invariant-statement]
+        d2 = {"x": i, "j": n}
+        d3 = {"j": n}
+
+    for n in range(2):
+        print("x" * n)
+ 
+    for n in range(2):
+        print("x" * i)  # [loop-invariant-statement]
